@@ -6,11 +6,12 @@ Baidu cloud API
 """
 import os
 from . import pre_check, user_lang
+from .. import qs_default_console, qs_error_string, qs_info_string
 try:
     import aip
 except ImportError:
-    from .. import qs_default_console, qs_error_string
     qs_default_console.log(qs_error_string, 'You need to install:' if user_lang != 'zh' else '你需要安装:', 'baidu-aip')
+    exit(0)
 
 
 class ImageDeal:
@@ -45,21 +46,24 @@ class ImageDeal:
         :return: None
         """
         if not os.path.exists(path) or not os.path.isfile(path):
-            from .. import qs_default_console, qs_error_string
             qs_default_console.log(qs_error_string, ('No file named: %s' if user_lang != 'zh' else '没有文件: %s') % path)
             return
         img_name = os.path.basename(path)
         img_name = img_name[:img_name.index('.')] + '_LG.' + '.'.join(img_name.split('.')[1:])
-        with open(path, 'rb') as f:
-            img = f.read()
-        img = self.client.imageQualityEnhance(img)
-        try:
-            img = ImageDeal.base64.b64decode(img['image'])
-            with open(img_name, 'wb') as f:
-                f.write(img)
-        except :
-            from pprint import pprint
-            pprint(img)
+
+        with qs_default_console.status(f'{qs_info_string} [bold white]{"Reading Image" if user_lang != "zh" else "读取图片"}: {path}') as status:
+            with open(path, 'rb') as f:
+                img = f.read()
+            status.update(status=f'{qs_info_string} {"Dealing..." if user_lang != "zh" else "处理中..."}')
+            img = self.client.imageQualityEnhance(img)
+            try:
+                status.update(status=f'{qs_info_string} {"Write to" if user_lang != "zh" else "写入"}: {img_name}')
+                img = ImageDeal.base64.b64decode(img['image'])
+                with open(img_name, 'wb') as f:
+                    f.write(img)
+            except :
+                qs_default_console.print(qs_error_string, img)
+        qs_default_console.print(qs_info_string, "Deal Done!" if user_lang != "zh" else "处理完成!")
 
 
 class AipNLP:
@@ -95,7 +99,6 @@ class AipNLP:
         try:
             res = self.client.ecnet(words)['item']['correct_query']
         except Exception as e:
-            from .. import qs_default_console, qs_error_string
             qs_default_console.log(qs_error_string, repr(e))
         else:
             return res
