@@ -103,17 +103,11 @@ class TxCOS:
         """
         from .. import qs_default_console, qs_info_string
         from ..NetTools.NormalDL import size_format
-        from rich.table import Table, Column
-        from rich.box import SIMPLE
+        from ..TuiTools.Table import qs_default_table
         from rich.text import Text
         bucket = bucket if bucket else self.df_bucket
         ls = self.client.list_objects(Bucket=bucket)['Contents']
-        tb = Table(
-            *([Column('File', justify="center"), Column('Size', justify="center")]
-              if user_lang != 'zh' else
-              [Column('文件', justify="center"), Column('体积', justify="center")])
-            , show_edge=False, row_styles=['none', 'dim'], box=SIMPLE, title='[bold underline]Tencnet COS'
-        )
+        tb = qs_default_table(['File', 'Size'] if user_lang != 'zh' else ['文件', '体积'], title='Tencnet COS')
         for obj in ls:
             tb.add_row(Text(obj['Key'], justify='left'), Text(size_format(int(obj['Size']), align=True), justify='right'))
         qs_default_console.print(qs_info_string, 'Bucket Url:' if user_lang != 'zh' else '桶链接:',
